summaryrefslogtreecommitdiffstats
path: root/kalarm/alarmevent.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/alarmevent.cpp')
-rw-r--r--kalarm/alarmevent.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kalarm/alarmevent.cpp b/kalarm/alarmevent.cpp
index d3956793..78e57ad1 100644
--- a/kalarm/alarmevent.cpp
+++ b/kalarm/alarmevent.cpp
@@ -48,12 +48,12 @@ TQString KAEvent::calVersionString() { return TQString::fromLatin1("1.5.0"); }
int KAEvent::calVersion() { return KAlarm::Version(1,5,0); }
// Custom calendar properties.
// Note that all custom property names are prefixed with X-KDE-KALARM- in the calendar file.
// - Event properties
-static const TQCString NEXT_RECUR_PROPERTY("NEXTRECUR"); // X-KDE-KALARM-NEXTRECUR property
-static const TQCString REPEAT_PROPERTY("REPEAT"); // X-KDE-KALARM-REPEAT property
+static const TQCString NEXT_RECUR_PROPERTY("NEXTRECUR"); // X-TDE-KALARM-NEXTRECUR property
+static const TQCString REPEAT_PROPERTY("REPEAT"); // X-TDE-KALARM-REPEAT property
// - General alarm properties
-static const TQCString TYPE_PROPERTY("TYPE"); // X-KDE-KALARM-TYPE property
+static const TQCString TYPE_PROPERTY("TYPE"); // X-TDE-KALARM-TYPE property
static const TQString FILE_TYPE = TQString::fromLatin1("FILE");
static const TQString AT_LOGIN_TYPE = TQString::fromLatin1("LOGIN");
static const TQString REMINDER_TYPE = TQString::fromLatin1("REMINDER");
@@ -64,14 +64,14 @@ static const TQString DATE_DEFERRAL_TYPE = TQString::fromLatin1("DATE_DE
static const TQString DISPLAYING_TYPE = TQString::fromLatin1("DISPLAYING"); // used only in displaying calendar
static const TQString PRE_ACTION_TYPE = TQString::fromLatin1("PRE");
static const TQString POST_ACTION_TYPE = TQString::fromLatin1("POST");
-static const TQCString NEXT_REPEAT_PROPERTY("NEXTREPEAT"); // X-KDE-KALARM-NEXTREPEAT property
+static const TQCString NEXT_REPEAT_PROPERTY("NEXTREPEAT"); // X-TDE-KALARM-NEXTREPEAT property
// - Display alarm properties
-static const TQCString FONT_COLOUR_PROPERTY("FONTCOLOR"); // X-KDE-KALARM-FONTCOLOR property
+static const TQCString FONT_COLOUR_PROPERTY("FONTCOLOR"); // X-TDE-KALARM-FONTCOLOR property
// - Email alarm properties
-static const TQCString EMAIL_ID_PROPERTY("EMAILID"); // X-KDE-KALARM-EMAILID property
+static const TQCString EMAIL_ID_PROPERTY("EMAILID"); // X-TDE-KALARM-EMAILID property
// - Audio alarm properties
-static const TQCString VOLUME_PROPERTY("VOLUME"); // X-KDE-KALARM-VOLUME property
-static const TQCString SPEAK_PROPERTY("SPEAK"); // X-KDE-KALARM-SPEAK property
+static const TQCString VOLUME_PROPERTY("VOLUME"); // X-TDE-KALARM-VOLUME property
+static const TQCString SPEAK_PROPERTY("SPEAK"); // X-TDE-KALARM-SPEAK property
// Event categories
static const TQString DATE_ONLY_CATEGORY = TQString::fromLatin1("DATE");
@@ -1065,7 +1065,7 @@ bool KAEvent::updateKCalEvent(Event& ev, bool checkUid, bool original, bool canc
if (!mMainExpired || original)
{
/* The alarm offset must always be zero for the main alarm. To determine
* which recurrence is due, the property X-KDE-KALARM_NEXTRECUR is used.
* If the alarm offset was non-zero, exception dates and rules would not
* work since they apply to the event time, not the alarm time.
*/
@@ -1216,7 +1216,7 @@ bool KAEvent::updateKCalEvent(Event& ev, bool checkUid, bool original, bool canc
/******************************************************************************
* Create a new alarm for a libkcal event, and initialise it according to the
* alarm action. If 'types' is non-null, it is appended to the X-KDE-KALARM-TYPE
* property value list.
*/
Alarm* KAEvent::initKCalAlarm(Event& event, const DateTime& dt, const TQStringList& types, KAAlarm::Type type) const
@@ -2650,7 +2650,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
static const TQString EXEC_IN_XTERM_CAT = TQString::fromLatin1("XTERM");
// KAlarm pre-1.4.22 properties
- static const TQCString KMAIL_ID_PROPERTY("KMAILID"); // X-KDE-KALARM-KMAILID property
+ static const TQCString KMAIL_ID_PROPERTY("KMAILID"); // X-TDE-KALARM-KMAILID property
if (version >= calVersion())
return;
@@ -2691,7 +2691,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
{
/*
* It's a KAlarm pre-0.9 calendar file.
* All alarms were of type DISPLAY. Instead of the X-KDE-KALARM-TYPE
* alarm property, characteristics were stored as a prefix to the
* alarm DESCRIPTION property, as follows:
* SETQNO;[FLAGS];TYPE:TEXT
@@ -2815,7 +2815,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
* Set the DTEND time to the DTSTART time.
* Convert all alarm times to DTSTART offsets.
* For display alarms, convert the first unlabelled category to an
- * X-KDE-KALARM-FONTCOLOUR property.
+ * X-TDE-KALARM-FONTCOLOUR property.
* Convert BEEP category into an audio alarm with no audio file.
*/
if (uidStatus(event->uid()) == EXPIRED)
@@ -2948,7 +2948,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
/*
* It's a KAlarm pre-1.4.14 calendar file.
* For recurring events, convert the main alarm offset to an absolute
* time in the X-KDE-KALARM-NEXTRECUR property, and convert main
* alarm offsets to zero and deferral alarm offsets to be relative to
* the next recurrence.
*/
@@ -48,12 +48,12 @@ TQString KAEvent::calVersionString() { return TQString::fromLatin1("1.5.0"); }
int KAEvent::calVersion() { return KAlarm::Version(1,5,0); }
// Custom calendar properties.
-// Note that all custom property names are prefixed with X-KDE-KALARM- in the calendar file.
+// Note that all custom property names are prefixed with X-TDE-KALARM- in the calendar file.
// - Event properties
@@ -1065,7 +1065,7 @@ bool KAEvent::updateKCalEvent(Event& ev, bool checkUid, bool original, bool canc
{
/* The alarm offset must always be zero for the main alarm. To determine
- * which recurrence is due, the property X-KDE-KALARM_NEXTRECUR is used.
+ * which recurrence is due, the property X-TDE-KALARM_NEXTRECUR is used.
* If the alarm offset was non-zero, exception dates and rules would not
* work since they apply to the event time, not the alarm time.
@@ -1216,7 +1216,7 @@ bool KAEvent::updateKCalEvent(Event& ev, bool checkUid, bool original, bool canc
/******************************************************************************
* Create a new alarm for a libkcal event, and initialise it according to the
- * alarm action. If 'types' is non-null, it is appended to the X-KDE-KALARM-TYPE
+ * alarm action. If 'types' is non-null, it is appended to the X-TDE-KALARM-TYPE
* property value list.
*/
@@ -2691,7 +2691,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
/*
* It's a KAlarm pre-0.9 calendar file.
- * All alarms were of type DISPLAY. Instead of the X-KDE-KALARM-TYPE
+ * All alarms were of type DISPLAY. Instead of the X-TDE-KALARM-TYPE
* alarm property, characteristics were stored as a prefix to the
* alarm DESCRIPTION property, as follows:
@@ -2948,7 +2948,7 @@ void KAEvent::convertKCalEvents(KCal::Calendar& calendar, int version, bool adju
* It's a KAlarm pre-1.4.14 calendar file.
* For recurring events, convert the main alarm offset to an absolute
- * time in the X-KDE-KALARM-NEXTRECUR property, and convert main
+ * time in the X-TDE-KALARM-NEXTRECUR property, and convert main
* alarm offsets to zero and deferral alarm offsets to be relative to
* the next recurrence.